from copy import copy

from django.urls.base import reverse
from edc_dashboard.url_names import url_names
from edc_lab.models import BoxItem

from ...model_wrappers import ManageBoxItemModelWrapper
from .base_box_item_listboard_view import BaseBoxItemListboardView


class ManageBoxListboardView(BaseBoxItemListboardView):
    action_name = "manage"
    form_action_url = "manage_box_item_form_action_url"
    listboard_url = "manage_box_listboard_url"
    listboard_template = "manage_box_listboard_template"
    verify_box_listboard_url = "verify_box_listboard_url"
    listboard_model = BoxItem
    model_wrapper_cls = ManageBoxItemModelWrapper
    navbar_selected_item = "pack"
    search_form_url = "manage_box_listboard_url"

    @property
    def url_kwargs(self):
        return {"action_name": self.action_name, "box_identifier": self.box_identifier}

    def get_context_data(self, **kwargs):
        context = super().get_context_data(**kwargs)
        url_kwargs = copy(self.url_kwargs)
        url_kwargs["position"] = 1
        url_kwargs["action_name"] = "verify"
        context.update(
            verify_box_listboard_url_reversed=reverse(
                url_names.get(self.verify_box_listboard_url), kwargs=url_kwargs
            )
        )
        return context



from django.test import TestCase
from edc_lab.models import Box, BoxItem, BoxType

from edc_lab_dashboard.templatetags.edc_lab_extras import verified


class TestTemplateTags(TestCase):
    def test_verified(self):
        box_type = BoxType.objects.create(name="9 x 9", across=9, down=9, total=81)
        box = Box.objects.create(box_identifier="12345678", box_type=box_type)
        box_item = BoxItem.objects.create(box=box, position=0, identifier="1")
        self.assertEqual(verified(box_item), "")
        box_item = BoxItem.objects.create(box=box, position=2, identifier="2", verified=True)
        self.assertIn("verified", verified(box_item))



from .aliquot_model_wrapper import AliquotModelWrapper
from .box_model_wrapper import BoxModelWrapper
from .manage_box_item_model_wrapper import ManageBoxItemModelWrapper
from .manifest_item_model_wrapper import ManifestItemModelWrapper
from .manifest_model_wrapper import ManifestModelWrapper
from .requisition_model_wrapper import RequisitionModelWrapper
from .result_model_wrapper import ResultModelWrapper
from .verify_box_model_wrapper import VerifyBoxItemModelWrapper



from django.conf.urls import include
from django.urls.conf import path
from django.views.generic.base import TemplateView
from edc_lab.admin_site import edc_lab_admin

urlpatterns = [
    path("admin/", edc_lab_admin.urls),
    path("edc_dashboard/", include("edc_dashboard.urls")),
    path("edc_device/", include("edc_device.urls")),
    path("edc_label/", include("edc_label.urls")),
    path("edc_lab/", include("edc_lab.urls")),
    path("edc_protocol/", include("edc_protocol.urls")),
    path("edc_lab_dashboard/", include("edc_lab_dashboard.urls")),
    path("", TemplateView.as_view(template_name="home.html"), name="administration_url"),
    path("", TemplateView.as_view(template_name="home.html"), name="logout"),
    path("", TemplateView.as_view(template_name="home.html"), name="home_url"),
]
